==> App-IndonesianHolidayUtils-0.061.tar.gz: App-IndonesianHolidayUtils-0.061/lib/App/IndonesianHolidayUtils.pm <==
package App::IndonesianHolidayUtils;

use 5.010001;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2021-01-17'; # DATE
our $DIST = 'App-IndonesianHolidayUtils'; # DIST
our $VERSION = '0.061'; # VERSION

1;
# ABSTRACT: List Indonesian holidays

__END__

=pod

=encoding UTF-8

=head1 NAME

App::IndonesianHolidayUtils - List Indonesian holidays

=head1 VERSION

This document describes version 0.061 of App::IndonesianHolidayUtils (from Perl distribution App-IndonesianHolidayUtils), released on 2021-01-17.

=head1 SYNOPSIS

This distribution contains several CLI's related to Indonesian holidays:

=over

=item * L<is-idn-holiday>

=item * L<list-idn-holidays>

=item * L<list-idn-workdays>

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-IndonesianHolidayUtils>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-IndonesianHolidayUtils>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-App-IndonesianHolidayUtils/issues>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<Calendar::Indonesia::Holiday>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2021, 2016, 2015 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

==> App-IndonesianHolidayUtils-0.062.tar.gz: App-IndonesianHolidayUtils-0.062/lib/App/IndonesianHolidayUtils.pm <==
package App::IndonesianHolidayUtils;

use 5.010001;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2021-03-07'; # DATE
our $DIST = 'App-IndonesianHolidayUtils'; # DIST
our $VERSION = '0.062'; # VERSION

1;
# ABSTRACT: List Indonesian holidays

__END__

=pod

=encoding UTF-8

=head1 NAME

App::IndonesianHolidayUtils - List Indonesian holidays

=head1 VERSION

This document describes version 0.062 of App::IndonesianHolidayUtils (from Perl distribution App-IndonesianHolidayUtils), released on 2021-03-07.

=head1 SYNOPSIS

This distribution contains several CLI's related to Indonesian holidays:

=over

=item * L<is-idn-holiday>

=item * L<list-idn-holidays>

=item * L<list-idn-workdays>

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-IndonesianHolidayUtils>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-IndonesianHolidayUtils>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-IndonesianHolidayUtils>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<Calendar::Indonesia::Holiday>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2021, 2016, 2015 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
